/*
 *  Copyright 2010 johan.
 * 
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 * 
 *       http://www.apache.org/licenses/LICENSE-2.0
 * 
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *  under the License.
 */

package nu.zoom.catonine.xml;

import java.awt.Color;
import javax.xml.bind.annotation.adapters.XmlAdapter;

/**
 * Adapter to de-/serialize a color to a String.
 * 
 * @see Color
 * 
 * @author "Johan Maasing" &lt;johan@zoom.nu&gt;
 */
public class JAXBColorAdapter extends XmlAdapter<String, Color> {

	@Override
	public Color unmarshal(String v) throws Exception {
		int parseInt = Integer.parseInt(v, 16);
		return new Color(parseInt);
	}

	@Override
	public String marshal(Color v) throws Exception {
		int colorRGB = v.getRGB();
		// Mask of Alpha
		colorRGB = colorRGB & 0x00ffffff;
		return "" + Integer.toHexString(colorRGB);
	}

}
